@@ -1,9 +1,9 @@
 ;;; -*- Mode:Emacs-Lisp -*-
 
 ;;; This file is the part of the Insidious Big Brother Database (aka BBDB),
-;;; copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@lucid.com>.
+;;; copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>.
 ;;; Most of the user-level interactive commands for BBDB.  See bbdb.texinfo.
-;;; last change 25-jan-94.
+;;; last change 22-mar-96.
 
 ;;; The Insidious Big Brother Database is free software; you can redistribute
 ;;; it and/or modify it under the terms of the GNU General Public License as
@@ -1096,11 +1096,10 @@ deleted."
   "Delete the entire bbdb database entry which the cursor is within."
   (interactive (list (bbdb-current-record t)))
   (if (or noprompt
-	  (prog1 (y-or-n-p (format "delete the entire db entry of %s? "
-				   (or (bbdb-record-name r)
-				       (bbdb-record-company r)
-				       (car (bbdb-record-net r)))))
-	    (message " ")))
+	  (bbdb-y-or-n-p (format "delete the entire db entry of %s? "
+				 (or (bbdb-record-name r)
+				     (bbdb-record-company r)
+				     (car (bbdb-record-net r))))))
       (let* ((record-cons (assq r bbdb-records))
 	     (next-record-cons (car (cdr (memq record-cons bbdb-records)))))
 	(bbdb-debug (if (bbdb-record-deleted-p r)
@@ -1230,9 +1229,10 @@ Completion behaviour is as dictated by the variable `bbdb-completion-type'."
 	 (cond ((and (/= 0 (length (bbdb-record-name old-record)))
 		     (/= 0 (length (bbdb-record-name new-record))))
 		(prog1
-		    (if (y-or-n-p (format "Use name \"%s\" instead of \"%s\"? "
-					  (bbdb-record-name old-record)
-					  (bbdb-record-name new-record)))
+		    (if (bbdb-y-or-n-p
+			 (format "Use name \"%s\" instead of \"%s\"? "
+				 (bbdb-record-name old-record)
+				 (bbdb-record-name new-record)))
 			(progn
 			  (setq extra-name new-record)
 			  (cons (bbdb-record-firstname old-record)
@@ -1241,7 +1241,7 @@ Completion behaviour is as dictated by the variable `bbdb-completion-type'."
 			(cons (bbdb-record-firstname new-record)
 			      (bbdb-record-lastname new-record)))
 		  (or (and bbdb-use-alternate-names
-			   (y-or-n-p
+			   (bbdb-y-or-n-p
 			     (format "Keep \"%s\" as an alternate name? "
 				     (bbdb-record-name extra-name))))
 		      (setq extra-name nil))
@@ -1254,7 +1254,8 @@ Completion behaviour is as dictated by the variable `bbdb-completion-type'."
 	(comp
 	 (cond ((and (/= 0 (length (bbdb-record-company old-record)))
 		     (/= 0 (length (bbdb-record-company new-record))))
-		(if (y-or-n-p (format "Use company \"%s\" instead of \"%s\"? "
+		(if (bbdb-y-or-n-p (format
+				    "Use company \"%s\" instead of \"%s\"? "
 				      (bbdb-record-company old-record)
 				      (bbdb-record-company new-record)))
 		    (bbdb-record-company old-record)
@@ -1553,7 +1554,7 @@ semantics of bbdb-completion-type."
 to bbdb-completion-type.  If the user just hits return, nil is returned.
 Otherwise, a valid response is forced."
   (let* ((ht (bbdb-hashtable))
-	 (string (completing-read prompt ht 'bbdb-completion-predicate))
+	 (string (completing-read prompt ht 'bbdb-completion-predicate t))
 	 (symbol (and (not (= 0 (length string)))
 		      (intern-soft string ht))))
     (if symbol
