@@ -1,13 +1,13 @@
 ;;; -*- Mode:Emacs-Lisp -*-
 
 ;;; This file is part of the Insidious Big Brother Database (aka BBDB),
-;;; copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@lucid.com>.
+;;; copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>.
 ;;; Various additional functionality for the BBDB.  See bbdb.texinfo.
-;;; last change  1-dec-93.
+;;; last change 19-jan-95.
 
 ;;; The Insidious Big Brother Database is free software; you can redistribute
 ;;; it and/or modify it under the terms of the GNU General Public License as
-;;; published by the Free Software Foundation; either version 1, or (at your
+;;; published by the Free Software Foundation; either version 2 or (at your
 ;;; option) any later version.
 ;;;
 ;;; BBDB is distributed in the hope that it will be useful, but WITHOUT ANY
@@ -437,8 +437,9 @@ the variables bbdb-auto-notes-alist and bbdb-auto-notes-ignore."
 (defvar bbdb-canonical-hosts
   (mapconcat 'regexp-quote
 	     '("cs.cmu.edu" "ri.cmu.edu" "edrc.cmu.edu" "andrew.cmu.edu"
-	       "lucid.com" "cenatls.cena.dgac.fr" "cenaath.cena.dgac.fr"
-	       "irit.fr" "enseeiht.fr" "inria.fr")
+	       "mcom.com" "netscape.com" "cenatls.cena.dgac.fr"
+	       "cenaath.cena.dgac.fr" "irit.fr" "enseeiht.fr" "inria.fr"
+	       "cs.uiuc.edu" "xemacs.org")
 	     "\\|")
   "Certain sites have a single mail-host; for example, all mail originating
 at hosts whose names end in \".cs.cmu.edu\" can (and probably should) be
@@ -498,7 +499,7 @@ which behave the same way.")
    ;;
    ;; Another local mail-configuration botch: sometimes mail shows up
    ;; with addresses like "user@workstation", where "workstation" is a
-   ;; local machine name.  That should really be "user" or "user@lucid.com".
+   ;; local machine name.  That should really be "user" or "user@netscape.com".
    ;; (I'm told this one is due to a bug in SunOS 4.1.1 sendmail.)
    ;;
    ((string-match "\\`\\([^@%!]+\\)[@%][^@%!.]+\\'" addr)
