@@ -1,7 +1,7 @@
 ;;; -*- Mode:Emacs-Lisp -*-
 
 ;;; This file is the core of the Insidious Big Brother Database (aka BBDB),
-;;; copyright (c) 1991, 1992, 1993, 1994 Jamie Zawinski <jwz@lucid.com>.
+;;; copyright (c) 1991, 1992, 1993, 1994 Jamie Zawinski <jwz@netscape.com>.
 ;;; See the file bbdb.texinfo for documentation.
 ;;;
 ;;; The Insidious Big Brother Database is free software; you can redistribute
@@ -18,22 +18,22 @@
 ;;; along with GNU Emacs; see the file COPYING.  If not, write to
 ;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 ;;;
-;;;  -----------------------------------------------------------------------
-;;; |  There is a mailing list for discussion of BBDB: info-bbdb@lucid.com. |
-;;; |  To join, send mail to info-bbdb-request@lucid.com (don't forget the  |
-;;; |  -request part or you'll look silly in front of lots of people who    |
-;;; |  have the ability to remember it indefinitely...)                     |
-;;; |                                                                       |
-;;; |  There is also a second mailing list, to which only bug fixes and     |
-;;; |  new version announcements are sent; to be added to it, send mail to  |
-;;; |  bbdb-announce-request@lucid.com.  This is a very low volume list,    |
-;;; |  and if you're using BBDB, you really should be on it.                |
-;;; |                                                                       |
-;;; |  When joining these lists or reporting bugs, please mention which     |
-;;; |  version you have.                                                    |
-;;;  -----------------------------------------------------------------------
+;;;  ------------------------------------------------------------------------
+;;; |  There is a mailing list for discussion of BBDB: info-bbdb@xemacs.org  |
+;;; |  To join, send mail to info-bbdb-request@xemacs.org (don't forget the  |
+;;; |  -request part or you'll look silly in front of lots of people who     |
+;;; |  have the ability to remember it indefinitely...)                      |
+;;; |                                                                        |
+;;; |  There is also a second mailing list, to which only bug fixes and      |
+;;; |  new version announcements are sent; to be added to it, send mail to   |
+;;; |  bbdb-announce-request@xemacs.org.  This is a very low volume list,    |
+;;; |  and if you're using BBDB, you really should be on it.                 |
+;;; |                                                                        |
+;;; |  When joining these lists or reporting bugs, please mention which      |
+;;; |  version you have.                                                     |
+;;;  ------------------------------------------------------------------------
 
-(defconst bbdb-version "1.50; 18-feb-94.")
+(defconst bbdb-version "1.51; 21-may-96.")
 (defconst bbdb-file-format 2)
 
 ;; This nonsense is to get the definition of defsubst loaded in when this file
@@ -302,10 +302,31 @@ Database code is first loaded.")
   (list 'and 'bbdb-debug (list 'let '((debug-on-error t)) (cons 'progn body)))
   )
 
-(defmacro bbdb-y-or-n-p (&rest args)
-  (list 'prog1
-	(cons 'y-or-n-p args)
-	'(message " ")))
+
+;;; internal kludge to force queries to always happen with the mouse rather
+;;; than basing the decision on the last-input-event; bind this, don't set it.
+(defvar bbdb-force-dialog-boxes nil)
+
+(defun bbdb-y-or-n-p (prompt)
+  (prog1
+      (cond ((and bbdb-force-dialog-boxes
+		  (fboundp 'yes-or-no-p-dialog-box))
+	     (if (and (fboundp 'raise-screen)
+		      (not (screen-visible-p (selected-screen))))
+		 (raise-screen (selected-screen)))
+	     (yes-or-no-p-dialog-box prompt))
+	    (t
+	     (y-or-n-p prompt)))
+    (message " ")))
+
+(defun bbdb-yes-or-no-p (prompt)
+  (prog1
+      (funcall (if (and bbdb-force-dialog-boxes
+			(fboundp 'yes-or-no-p-dialog-box))
+		   'yes-or-no-p-dialog-box
+		 'yes-or-no-p)
+	       prompt)
+    (message " ")))
 
 (defun bbdb-invoke-hook (hook arg)
   "Like invoke-hooks, but invokes the given hook with one argument."
@@ -1025,7 +1046,7 @@ optional arg DONT-CHECK-DISK is non-nil (which is faster, but hazardous.)"
 	       (setq shut-up t)
 	       (revert-buffer t t))
 	      ;; hassle the user
-	      ((yes-or-no-p (if (buffer-modified-p buf)
+	      ((bbdb-yes-or-no-p (if (buffer-modified-p buf)
 				"BBDB has changed on disk; flush your changes and revert? "
 				"BBDB has changed on disk; revert? "))
 	       (or (file-exists-p bbdb-file)
@@ -1075,7 +1096,7 @@ optional arg DONT-CHECK-DISK is non-nil (which is faster, but hazardous.)"
 		   (cond ((and bbdb-notice-auto-save-file
 			       (file-newer-than-file-p (make-auto-save-file-name)
 						       buffer-file-name))
-			  (if (yes-or-no-p "BBDB auto-save file is newer; recover it? ")
+			  (if (bbdb-yes-or-no-p "BBDB auto-save file is newer; recover it? ")
 			      (progn
 				(recover-file buffer-file-name)
 				(bury-buffer (current-buffer)) ; recover-file selects it
@@ -1566,7 +1587,7 @@ The keybindings, more precisely:
 (defvar bbdb-save-db-timeout nil
   "*If non-nil, then when bbdb-save-db is asking you whether to save the db,
 it will time out to `yes' after this many seconds.  This only works if the
-function y-or-n-p-with-timeout is defined (meaning Lucid Emacs.)")
+function y-or-n-p-with-timeout is defined (meaning XEmacs.)")
 
 (defun bbdb-save-db (&optional prompt-first mention-if-not-saved)
   "save the db if it is modified."
@@ -1818,7 +1839,9 @@ If CREATE-P is true, then a record may be created, otherwise it won't.
 If PROMPT-TO-CREATE-P is true, then the user will be asked for confirmation
 before the record is created, otherwise it is created without confirmation 
 \(assuming that CREATE-P is true\).  "
-  (let* ((data (mail-extract-address-components from))
+  (let* ((data (if (consp from)
+		   from ; if from is a cons, it's pre-parsed (hack hack)
+		 (mail-extract-address-components from)))
 	 (name (car data))
 	 (net (car (cdr data))))
     (if (equal name net) (setq name nil))
@@ -2213,8 +2236,8 @@ the window will be split vertically rather than horizontally."
 (autoload 'sample-bbdb-canonicalize-net-hook "bbdb-hooks" bbdbid nil)
 (autoload 'bbdb-creation-date-hook	     "bbdb-hooks" bbdbid nil)
 
-(autoload 'bbdb-fontify-buffer	"bbdb-lucid" bbdbid nil)
-(autoload 'bbdb-menu		"bbdb-lucid" bbdbid t)
+(autoload 'bbdb-fontify-buffer	"bbdb-xemacs" bbdbid nil)
+(autoload 'bbdb-menu		"bbdb-xemacs" bbdbid t)
 
 (makunbound 'bbdbid)
 
@@ -2243,7 +2266,7 @@ the window will be split vertically rather than horizontally."
 (if (featurep 'mh-e)  (safe-require 'bbdb-mhe))
 
 ;;; elucidate
-(cond ((string-match "Lucid" emacs-version)
+(cond ((string-match "XEmacs\\|Lucid" emacs-version)
        (bbdb-add-hook 'bbdb-list-hook 'bbdb-fontify-buffer)
        (define-key bbdb-mode-map 'button3 'bbdb-menu)
        ))
