@@ -3,25 +3,27 @@
 ;; Copyright (C) 1991, 1992, 1993, 1994 Free Software Foundation, Inc.
 
 ;; Author: Joe Wells <jbw@cs.bu.edu>
-;; Maintainer: Jamie Zawinski <jwz@lucid.com>
-;; Version: 1.7
+;; Maintainer: Jamie Zawinski <jwz@netscape.com>
+;; Version: 1.8
 ;; Keywords: mail
 
-;; This file is part of GNU Emacs.
+;; This file is part of XEmacs.
 
-;; GNU Emacs is free software; you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
+;; XEmacs is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
 ;; the Free Software Foundation; either version 2, or (at your option)
 ;; any later version.
 
-;; GNU Emacs is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;; GNU General Public License for more details.
+;; XEmacs is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; along with XEmacs; see the file COPYING.  If not, write to the Free
+;; Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+
+;;; Synched up with: Not synched with FSF but close to 19.28.
 
 ;;; Commentary:
 
@@ -118,19 +120,19 @@
 
 ;;; Change Log: 
 ;; 
-;; Thu Feb 17 17:57:33 1994  Jamie Zawinski (jwz@lucid.com)
+;; Thu Feb 17 17:57:33 1994  Jamie Zawinski (jwz@netscape.com)
 ;;
 ;;	* merged with jbw's latest version
 ;;
-;; Wed Feb  9 21:56:27 1994  Jamie Zawinski (jwz@lucid.com)
+;; Wed Feb  9 21:56:27 1994  Jamie Zawinski (jwz@netscape.com)
 ;;
 ;;      * high-bit chars in comments weren't treated as word syntax
 ;;
-;; Sat Feb  5 03:13:40 1994  Jamie Zawinski (jwz@lucid.com)
+;; Sat Feb  5 03:13:40 1994  Jamie Zawinski (jwz@netscape.com)
 ;;
 ;;      * call replace-match with fixed-case arg
 ;;
-;; Thu Dec 16 21:56:45 1993  Jamie Zawinski (jwz@lucid.com)
+;; Thu Dec 16 21:56:45 1993  Jamie Zawinski (jwz@netscape.com)
 ;;
 ;;      * some more cleanup, doc, added provide
 ;;
@@ -516,6 +518,7 @@ by translating things like \"foo!bar!baz@host\" into \"baz@bar.UUCP\".")
     (?! ?~	 "w")			;printable characters
     (?\177	 "w")			;DEL
     (?\200 ?\377 "w")			;high-bit-on characters
+    (?\240	 " ")			;nobreakspace
     (?\t " ")
     (?\r " ")
     (?\n " ")
@@ -539,6 +542,7 @@ by translating things like \"foo!bar!baz@host\" into \"baz@bar.UUCP\".")
    (mail-extr-address-comment-syntax-table
     (?\000 ?\377 "w")
     (?\040 " ")
+    (?\240 " ")
     (?\t " ")
     (?\r " ")
     (?\n " ")
@@ -548,6 +552,7 @@ by translating things like \"foo!bar!baz@host\" into \"baz@bar.UUCP\".")
    (mail-extr-address-domain-literal-syntax-table
     (?\000 ?\377 "w")
     (?\040 " ")
+    (?\240 " ")
     (?\t " ")
     (?\r " ")
     (?\n " ")
@@ -557,6 +562,7 @@ by translating things like \"foo!bar!baz@host\" into \"baz@bar.UUCP\".")
    (mail-extr-address-text-comment-syntax-table
     (?\000 ?\377 "w")
     (?\040 " ")
+    (?\240 " ")
     (?\t " ")
     (?\r " ")
     (?\n " ")
@@ -573,7 +579,7 @@ by translating things like \"foo!bar!baz@host\" into \"baz@bar.UUCP\".")
     )
    (mail-extr-address-text-syntax-table
     (?\000 ?\177 ".")
-    (?\200 ?\377 "w")	;assume high-bit is word constituent
+    (?\200 ?\377 "w")
     (?\040 " ")
     (?\t " ")
     (?\r " ")
@@ -601,16 +607,12 @@ by translating things like \"foo!bar!baz@host\" into \"baz@bar.UUCP\".")
   (list 'delete-region '(point) (list '+ '(point) n)))
 
 (defmacro mail-extr-skip-whitespace-forward ()
-  ;; #### compile-time dependence on v18/v19
-  (if (fboundp 'skip-syntax-forward)
-      '(skip-syntax-forward " ")
-    '(skip-chars-forward " \t\n")))
+  ;; v19 fn skip-syntax-forward is more tasteful, but not byte-coded.
+  '(skip-chars-forward " \t\n\r\240"))
 
 (defmacro mail-extr-skip-whitespace-backward ()
-  ;; #### compile-time dependence on v18/v19
-  (if (fboundp 'skip-syntax-backward)
-      '(skip-syntax-backward " ")
-    '(skip-chars-backward " \t\n")))
+  ;; v19 fn skip-syntax-backward is more tasteful, but not byte-coded.
+  '(skip-chars-backward " \t\n\r\240"))
 
 
 (defmacro mail-extr-undo-backslash-quoting (beg end)
@@ -628,7 +630,7 @@ by translating things like \"foo!bar!baz@host\" into \"baz@bar.UUCP\".")
 (defmacro mail-extr-nuke-char-at (pos)
   (` (save-excursion
        (goto-char (, pos))
-       (delete-region (point) (1+ (point)))
+       (mail-extr-delete-char 1)
        (insert ?\ ))))
 
 (put 'mail-extr-nuke-outside-range
@@ -724,8 +726,8 @@ If ADDRESS contains more than one RFC-822 address, only the first is
 	(extraction-buffer (get-buffer-create " *extract address components*"))
 	char
 ;;	multiple-addresses
-	<-pos >-pos @-pos :-pos ,-pos !-pos %-pos \;-pos
-	group-:-pos group-\;-pos route-addr-:-pos
+	<-pos >-pos @-pos colon-pos comma-pos !-pos %-pos \;-pos
+	group-colon-pos group-\;-pos route-addr-colon-pos
 	record-pos-symbol
 	first-real-pos last-real-pos
 	phrase-beg phrase-end
@@ -761,7 +763,7 @@ If ADDRESS contains more than one RFC-822 address, only the first is
       (cond ((stringp address)
 	     (insert address))
 	    ((bufferp address)
-	     (insert-buffer address))
+	     (insert-buffer-substring address))
 	    (t
 	     (error "Illegal address: %s" address)))
       
@@ -843,7 +845,7 @@ If ADDRESS contains more than one RFC-822 address, only the first is
 	 ((setq record-pos-symbol
 		(cdr (assq char
 			   '((?< . <-pos) (?> . >-pos) (?@ . @-pos)
-			     (?: . :-pos) (?, . ,-pos) (?! . !-pos)
+			     (?: . colon-pos) (?, . comma-pos) (?! . !-pos)
 			     (?% . %-pos) (?\; . \;-pos)))))
 	  (set record-pos-symbol
 	       (cons (point) (symbol-value record-pos-symbol)))
@@ -883,7 +885,7 @@ If ADDRESS contains more than one RFC-822 address, only the first is
       ;; Example: @foo.bar.dom,@xxx.yyy.zzz:mailbox@aaa.bbb.ccc
       ;; This commonly happens on the UUCP "From " line.  Ugh.
       (cond ((and (> (length @-pos) 1)
-		  (eq 1 (length :-pos))	;TODO: check if between last two @s
+		  (eq 1 (length colon-pos))	;TODO: check if between last two @s
 		  (not \;-pos)
 		  (not <-pos))
 	     (goto-char (point-min))
@@ -923,22 +925,22 @@ If ADDRESS contains more than one RFC-822 address, only the first is
       ;; Check for : that indicates GROUP list and for : part of
       ;; ROUTE-ADDR spec.
       ;; Can't possibly be more than two :.  Nuke any extra.
-      (while :-pos
-	(setq temp (car :-pos)
-	      :-pos (cdr :-pos))
+      (while colon-pos
+	(setq temp (car colon-pos)
+	      colon-pos (cdr colon-pos))
 	(cond ((and <-pos >-pos
 		    (> temp <-pos)
 		    (< temp >-pos))
-	       (if (or route-addr-:-pos
+	       (if (or route-addr-colon-pos
 		       (< (length @-pos) 2)
 		       (> temp (car @-pos))
 		       (< temp (nth 1 @-pos)))
 		   (mail-extr-nuke-char-at temp)
-		 (setq route-addr-:-pos temp)))
+		 (setq route-addr-colon-pos temp)))
 	      ((or (not <-pos)
 		   (and <-pos
 			(< temp <-pos)))
-	       (setq group-:-pos temp))))
+	       (setq group-colon-pos temp))))
       
       ;; Nuke any ; that is in or to the left of a < > pair or to the left
       ;; of a GROUP starting :.  Also, there may only be one ;.
@@ -949,17 +951,17 @@ If ADDRESS contains more than one RFC-822 address, only the first is
 		    (> temp <-pos)
 		    (< temp >-pos))
 	       (mail-extr-nuke-char-at temp))
-	      ((and (or (not group-:-pos)
-			(> temp group-:-pos))
+	      ((and (or (not group-colon-pos)
+			(> temp group-colon-pos))
 		    (not group-\;-pos))
 	       (setq group-\;-pos temp))))
       
       ;; Nuke unmatched GROUP syntax characters.
-      (cond ((and group-:-pos (not group-\;-pos))
+      (cond ((and group-colon-pos (not group-\;-pos))
 	     ;; *** Do I really need to erase it?
-	     (mail-extr-nuke-char-at group-:-pos)
-	     (setq group-:-pos nil)))
-      (cond ((and group-\;-pos (not group-:-pos))
+	     (mail-extr-nuke-char-at group-colon-pos)
+	     (setq group-colon-pos nil)))
+      (cond ((and group-\;-pos (not group-colon-pos))
 	     ;; *** Do I really need to erase it?
 	     (mail-extr-nuke-char-at group-\;-pos)
 	     (setq group-\;-pos nil)))
@@ -969,10 +971,10 @@ If ADDRESS contains more than one RFC-822 address, only the first is
       (cond
        (group-\;-pos
 	;; this is fine for now
-	(mail-extr-nuke-outside-range !-pos group-:-pos group-\;-pos t)
-	(mail-extr-nuke-outside-range @-pos group-:-pos group-\;-pos t)
-	(mail-extr-nuke-outside-range %-pos group-:-pos group-\;-pos t)
-	(mail-extr-nuke-outside-range ,-pos group-:-pos group-\;-pos t)
+	(mail-extr-nuke-outside-range !-pos group-colon-pos group-\;-pos t)
+	(mail-extr-nuke-outside-range @-pos group-colon-pos group-\;-pos t)
+	(mail-extr-nuke-outside-range %-pos group-colon-pos group-\;-pos t)
+	(mail-extr-nuke-outside-range comma-pos group-colon-pos group-\;-pos t)
 	(and last-real-pos
 	     (> last-real-pos (1+ group-\;-pos))
 	     (setq last-real-pos (1+ group-\;-pos)))
@@ -998,7 +1000,7 @@ If ADDRESS contains more than one RFC-822 address, only the first is
       ;; Hell, go ahead an nuke all of the commas.
       ;; **** This will cause problems when we start handling commas in
       ;; the PHRASE part .... no it won't ... yes it will ... ?????
-      (mail-extr-nuke-outside-range ,-pos 1 1)
+      (mail-extr-nuke-outside-range comma-pos 1 1)
       
       ;; can only have multiple @s inside < >.  The fact that some MTAs
       ;; put de-bracketed ROUTE-ADDRs in the UUCP-style "From " line is
@@ -1009,7 +1011,7 @@ If ADDRESS contains more than one RFC-822 address, only the first is
 	     (goto-char <-pos)
 	     (mail-extr-skip-whitespace-backward)
 	     (setq phrase-end (point))
-	     (goto-char (or ;;group-:-pos
+	     (goto-char (or ;;group-colon-pos
 			    (point-min)))
 	     (mail-extr-skip-whitespace-forward)
 	     (if (< (point) phrase-end)
@@ -1020,11 +1022,11 @@ If ADDRESS contains more than one RFC-822 address, only the first is
       ;; If there are multiple @s, then we assume ROUTE-ADDR syntax, and
       ;; any % or ! must be semantically meaningless.
       ;; TODO: do this processing into canonicalization buffer
-      (cond (route-addr-:-pos
+      (cond (route-addr-colon-pos
 	     (setq !-pos nil
 		   %-pos nil
 		   >-pos (copy-marker >-pos)
-		   route-addr-:-pos (copy-marker route-addr-:-pos))
+		   route-addr-colon-pos (copy-marker route-addr-colon-pos))
 	     (goto-char >-pos)
 	     (insert-before-markers ?X)
 	     (goto-char (car @-pos))
@@ -1035,16 +1037,16 @@ If ADDRESS contains more than one RFC-822 address, only the first is
 	       (goto-char (1- >-pos))
 	       (save-excursion
 		 (insert-buffer-substring extraction-buffer
-					  (car @-pos) route-addr-:-pos)
-		 (delete-region (car @-pos) route-addr-:-pos))
+					  (car @-pos) route-addr-colon-pos)
+		 (delete-region (car @-pos) route-addr-colon-pos))
 	       (or (cdr @-pos)
 		   (setq saved-@-pos (list (point)))))
 	     (setq @-pos saved-@-pos)
 	     (goto-char >-pos)
 	     (mail-extr-delete-char -1)
-	     (mail-extr-nuke-char-at route-addr-:-pos)
-	     (mail-extr-demarkerize route-addr-:-pos)
-	     (setq route-addr-:-pos nil
+	     (mail-extr-nuke-char-at route-addr-colon-pos)
+	     (mail-extr-demarkerize route-addr-colon-pos)
+	     (setq route-addr-colon-pos nil
 		   >-pos (mail-extr-demarkerize >-pos)
 		   %-pos (mapcar 'mail-extr-demarkerize %-pos))))
       
@@ -1372,7 +1374,7 @@ If ADDRESS contains more than one RFC-822 address, only the first is
 
       ;; If name is "First Last" and userid is "F?L", then assume
       ;; the middle initial is the second letter in the userid.
-      ;; Initial code by Jamie Zawinski <jwz@lucid.com>
+      ;; Initial code by Jamie Zawinski <jwz@netscape.com>
       ;; *** Make it work when there's a suffix as well.
       (goto-char (point-min))
       (cond ((and mail-extr-guess-middle-initial
@@ -1695,21 +1697,21 @@ If ADDRESS contains more than one RFC-822 address, only the first is
 	  (goto-char name-end)
 	  (setq word-found-flag t))
 
-	 ;; #### Perhaps better behavior here would be to leave the whole
-	 ;; rest of the line intact, assuming it's a sentence of some kind
-	 ;; like "face iz white! eyes iz tired!".
 	 (t
-	  (setq name-done-flag t)))
+	  (setq name-done-flag t)
+	  ))
 	
 	;; Count any word that we skipped over.
 	(if word-found-flag
 	    (setq word-count (1+ word-count))))
       
-      ;; If the last thing in the name is 2 or more periods (an elipsis) then
-      ;; keep them and the preceeding word.  This is for the benefit of whole
-      ;; sentences in the name field: it's better behavior than dropping the
-      ;; last word of the sentence...
-      (if (and (not suffix-flag) (looking-at "\\.+\\'"))
+      ;; If the last thing in the name is 2 or more periods, or one or more
+      ;; other sentence terminators (but not a single period) then keep them
+      ;; and the preceeding word.  This is for the benefit of whole sentences
+      ;; in the name field: it's better behavior than dropping the last word
+      ;; of the sentence...
+      (if (and (not suffix-flag)
+	       (looking-at "\\(\\.+\\|[?!;:.][?!;:.]+\\|[?!;:][?!;:.]*\\)\\'"))
 	  (goto-char (setq suffix-flag (point-max))))
 
       ;; Drop everything after point and certain trailing words.
